@@ -3,7 +3,7 @@ package Net::FTP::Find;
 use strict;
 use warnings;
 
-our $VERSION = '0.034';
+our $VERSION = '0.040';
 
 use Carp;
 use File::Spec;
@@ -22,7 +22,7 @@ __END__
 
 =head1 NAME
 
-Net::FTP::Find - Traverse a directory tree through Net::FTP
+Net::FTP::Find - Traverse a directory tree through Net::FTP (or Net::FTPSSL)
 
 =head1 SYNOPSIS
 
@@ -47,6 +47,18 @@ or
 
   $ftp->finddepth(sub { ... }, '/');
 
+or
+
+  use Net::FTPSSL;
+  use Net::FTP::Find::Mixin qw(Net::FTPSSL);
+
+  my $ftp = Net::FTPSSL->new('localhost');
+  $ftp->login('user', 'pass');
+
+  $ftp->find(sub { ... }, '/');
+
+  $ftp->finddepth(sub { ... }, '/');
+
 =head1 DESCRIPTION
 
 These are functions for searching through directory trees doing work on each
@@ -106,6 +118,20 @@ The directories that are deeper than this value is traversed.
 
 The directories that are shallower than this value is traversed.
 
+=item C<use_mlsd>
+
+If true, Net::FTP::Find tries to use the "MLSD" to retrieve entries.
+By using the "MLSD", we can fetch "mtime" of each file effectivly.
+Net::FTP::Find use the "LIST" instead automatically if the "MLSD" cannot be used.
+Default value is "1".
+
+=item C<fetch_mtime>
+
+If true, Net::FTP::Find tries to fetch "mtime" of each file.
+When "MLSD" can be used, "mtime" is fetched with file list.
+When "MLSD" cannot be used, "mtime" is fetched by using "MDTM" internally.
+Default value is "0".
+
 =back
 
 
@@ -128,6 +154,26 @@ through a collection of variables.
 
 =item C<$Net::FTP::Find::name> is the complete pathname to the file.
 
+=item C<$Net::FTP::Find::is_directory> is 1 if C<$_> is directory.
+
+=back
+
+These variables may be able to use if server is supporting.
+
+=over 4
+
+=item C<$Net::FTP::Find::mtime> is modification time (Unix epoch). this value is generated by parsing "YYYYMMDDHHMMSS" as GMT. If a server returns mtime as JST, this value may not be correct.
+
+=item C<$Net::FTP::Find::is_symlink> is 1 if C<$_> is symlink.
+
+=item C<$Net::FTP::Find::mode> is mode.
+
+=item C<$Net::FTP::Find::user> is owner name.
+
+=item C<$Net::FTP::Find::group> is group name.
+
+=item C<$Net::FTP::Find::size> is file size in bytes.
+
 =back
 
 The above variables have all been localized and may be changed without
@@ -163,11 +209,15 @@ table below summarizes all variants:
 
 Taku Amano E<lt>taku@toi-planning.netE<gt>
 
+Some part of code about L<Net::FTPSSL> is referred to L<Net::FTPSSL>.
+
 A mostly parts of the document are from L<File::Find>.
 
 =head1 SEE ALSO
 
 L<File::Find>
+L<Net::FTP>
+L<Net::FTPSSL>
 L<Net::FTP::Find::Mixin>
 
 =head1 LICENSE
